@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -14,11 +14,14 @@ from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases as database
 from flask import render_template, request, jsonify
-from flask_babel import gettext
+from flask_babelex import gettext
 from pgadmin.browser.collection import CollectionNodeModule
+from pgadmin.browser.server_groups.servers.databases.schemas.tables.\
+    partitions import backend_supported
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
     make_response as ajax_response, gone
+from pgadmin.utils.compile_template_name import compile_template_path
 from pgadmin.utils.driver import get_driver
 from config import PG_DEFAULT_DRIVER
 from pgadmin.utils import IS_PY2
@@ -72,19 +75,10 @@ class IndexesModule(CollectionNodeModule):
         if super(IndexesModule, self).BackendSupported(manager, **kwargs):
             conn = manager.connection(did=kwargs['did'])
 
-            # In case of partitioned table return false.
-            if 'tid' in kwargs and manager.version >= 100000:
-                partition_path = 'partition/sql/#{0}#'.format(manager.version)
-                SQL = render_template(
-                    "/".join([partition_path, 'backend_support.sql']),
-                    tid=kwargs['tid']
-                )
-                status, res = conn.execute_scalar(SQL)
-
-                # check if any errors
-                if not status:
-                    return internal_server_error(errormsg=res)
-                return not res
+            # If PG version > 100000 and < 110000 then index is
+            # not supported for partitioned table.
+            if 'tid' in kwargs and 100000 <= manager.version < 110000:
+                return not backend_supported(self, manager, **kwargs)
 
             if 'vid' not in kwargs:
                 return True
@@ -127,6 +121,14 @@ class IndexesModule(CollectionNodeModule):
         """
         return False
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 blueprint = IndexesModule(__name__)
 
@@ -250,7 +252,11 @@ class IndexesView(PGChildNodeView):
                 kwargs['did'] in self.manager.db_info else 0
 
             # we will set template path for sql scripts
-            self.template_path = 'index/sql/#{0}#'.format(self.manager.version)
+            self.template_path = compile_template_path(
+                'index/sql/',
+                self.manager.server_type,
+                self.manager.version
+            )
 
             # We need parent's name eg table name and schema name
             # when we create new index in update we can fetch it using
@@ -369,7 +375,8 @@ class IndexesView(PGChildNodeView):
     @check_precondition
     def list(self, gid, sid, did, scid, tid):
         """
-        This function is used to list all the schema nodes within that collection.
+        This function is used to list all the schema nodes within that
+        collection.
 
         Args:
             gid: Server group ID
@@ -397,8 +404,8 @@ class IndexesView(PGChildNodeView):
     @check_precondition
     def node(self, gid, sid, did, scid, tid, idx):
         """
-        This function will used to create all the child node within that collection.
-        Here it will create all the schema node.
+        This function will used to create all the child node within that
+        collection. Here it will create all the schema node.
 
         Args:
             gid: Server Group ID
@@ -423,11 +430,11 @@ class IndexesView(PGChildNodeView):
             return gone(gettext("""Could not find the index in the table."""))
 
         res = self.blueprint.generate_browser_node(
-                rset['rows'][0]['oid'],
-                tid,
-                rset['rows'][0]['name'],
-                icon="icon-index"
-            )
+            rset['rows'][0]['oid'],
+            tid,
+            rset['rows'][0]['name'],
+            icon="icon-index"
+        )
 
         return make_json_response(
             data=res,
@@ -437,8 +444,8 @@ class IndexesView(PGChildNodeView):
     @check_precondition
     def nodes(self, gid, sid, did, scid, tid):
         """
-        This function will used to create all the child node within that collection.
-        Here it will create all the schema node.
+        This function will used to create all the child node within that
+        collection. Here it will create all the schema node.
 
         Args:
             gid: Server Group ID
@@ -472,7 +479,7 @@ class IndexesView(PGChildNodeView):
             status=200
         )
 
-    def _column_details(self, idx, data):
+    def _column_details(self, idx, data, mode='properties'):
         """
         This functional will fetch list of column details for index
 
@@ -496,8 +503,10 @@ class IndexesView(PGChildNodeView):
         cols = []
         for row in rset['rows']:
             # We need all data as collection for ColumnsModel
+            # we will not strip down colname when using in SQL to display
             cols_data = {
-                'colname': row['attdef'].strip('"'),
+                'colname': row['attdef'] if mode == 'create' else
+                row['attdef'].strip('"'),
                 'collspcname': row['collnspname'],
                 'op_class': row['opcname'],
             }
@@ -519,10 +528,35 @@ class IndexesView(PGChildNodeView):
         # Push as collection
         data['columns'] = columns
         # Push as string
-        data['cols'] = ', '.join(cols)
+        data['columns_csv'] = ', '.join(cols)
 
         return data
 
+    def _include_details(self, idx, data, mode='properties'):
+        """
+        This functional will fetch list of include details for index
+        supported with Postgres 11+
+
+        Args:
+            idx: Index OID
+            data: Properties data
+
+        Returns:
+            Updated properties data with include details
+        """
+
+        SQL = render_template(
+            "/".join([self.template_path, 'include_details.sql']), idx=idx
+        )
+        status, rset = self.conn.execute_2darray(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=rset)
+
+        # Push as collection
+        data['include'] = [col['colname'] for col in rset['rows']]
+        return data
+
     @check_precondition
     def properties(self, gid, sid, did, scid, tid, idx):
         """
@@ -560,6 +594,10 @@ class IndexesView(PGChildNodeView):
         # Add column details for current index
         data = self._column_details(idx, data)
 
+        # Add Include details of the index
+        if self.manager.version >= 110000:
+            data = self._include_details(idx, data)
+
         return ajax_response(
             response=data,
             status=200
@@ -820,7 +858,9 @@ class IndexesView(PGChildNodeView):
             if not status:
                 return internal_server_error(errormsg=res)
             if len(res['rows']) == 0:
-                return gone(gettext("""Could not find the index in the table."""))
+                return gone(
+                    gettext("""Could not find the index in the table.""")
+                )
 
             old_data = dict(res['rows'][0])
 
@@ -893,7 +933,11 @@ class IndexesView(PGChildNodeView):
         data['table'] = self.table
 
         # Add column details for current index
-        data = self._column_details(idx, data)
+        data = self._column_details(idx, data, 'create')
+
+        # Add Include details of the index
+        if self.manager.version >= 110000:
+            data = self._include_details(idx, data, 'create')
 
         SQL, name = self.get_sql(did, scid, tid, None, data)
         if not isinstance(SQL, (str, unicode)):
