@@ -164,6 +164,9 @@ define('misc.statistics', [
               pgBrowser.Events.on(
                 'pgadmin-browser:tree:selected', this.showStatistics
               );
+              pgBrowser.Events.on(
+                'pgadmin-browser:tree:refreshing', this.refreshStatistics, this
+              );
             }
           }.bind(this)
         );
@@ -173,12 +176,18 @@ define('misc.statistics', [
           pgBrowser.Events.on(
             'pgadmin-browser:tree:selected', this.showStatistics
           );
+          pgBrowser.Events.on(
+            'pgadmin-browser:tree:refreshing', this.refreshStatistics, this
+          );
         }
       }
       if (self.panel.length > 0 && self.panel[0].isVisible()) {
         pgBrowser.Events.on(
           'pgadmin-browser:tree:selected', this.showStatistics
         );
+        pgBrowser.Events.on(
+          'pgadmin-browser:tree:refreshing', this.refreshStatistics, this
+        );
       }
     },
 
@@ -229,65 +238,65 @@ define('misc.statistics', [
                 }
               }, 1000);
             },
-            success: function(res) {
-              // clear timer and reset message.
-              clearTimeout(timer);
-              $msgContainer.text('');
-              if (res.data) {
-                var data = res.data;
-                if (node.hasCollectiveStatistics || data['rows'].length > 1) {
-                  self.__createMultiLineStatistics.call(self, data, node.statsPrettifyFields);
-                } else {
-                  self.__createSingleLineStatistics.call(self, data, node.statsPrettifyFields);
-                }
-
-                if (self.grid) {
-                  delete self.grid;
-                  self.grid = null;
-                }
-
-                self.grid = new Backgrid.Grid({
-                  columns: self.columns,
-                  collection: self.collection,
-                  className: GRID_CLASSES,
-                });
-                self.grid.render();
-                $gridContainer.empty();
-                $gridContainer.append(self.grid.$el);
-
-                if (!$msgContainer.hasClass('hidden')) {
-                  $msgContainer.addClass('hidden');
-                }
-                $gridContainer.removeClass('hidden');
-
-              } else if (res.info) {
-                if (!$gridContainer.hasClass('hidden')) {
-                  $gridContainer.addClass('hidden');
-                }
-                $msgContainer.text(res.info);
-                $msgContainer.removeClass('hidden');
+          })
+          .done(function(res) {
+            // clear timer and reset message.
+            clearTimeout(timer);
+            $msgContainer.text('');
+            if (res.data) {
+              var data = res.data;
+              if (node.hasCollectiveStatistics || data['rows'].length > 1) {
+                self.__createMultiLineStatistics.call(self, data, node.statsPrettifyFields);
+              } else {
+                self.__createSingleLineStatistics.call(self, data, node.statsPrettifyFields);
               }
-            },
-            error: function(xhr, error, message) {
-              var _label = treeHierarchy[n_type].label;
-              pgBrowser.Events.trigger(
-                'pgadmin:node:retrieval:error', 'statistics', xhr, error, message, item
+
+              if (self.grid) {
+                delete self.grid;
+                self.grid = null;
+              }
+
+              self.grid = new Backgrid.Grid({
+                columns: self.columns,
+                collection: self.collection,
+                className: GRID_CLASSES,
+              });
+              self.grid.render();
+              $gridContainer.empty();
+              $gridContainer.append(self.grid.$el);
+
+              if (!$msgContainer.hasClass('hidden')) {
+                $msgContainer.addClass('hidden');
+              }
+              $gridContainer.removeClass('hidden');
+
+            } else if (res.info) {
+              if (!$gridContainer.hasClass('hidden')) {
+                $gridContainer.addClass('hidden');
+              }
+              $msgContainer.text(res.info);
+              $msgContainer.removeClass('hidden');
+            }
+          })
+          .fail(function(xhr, error, message) {
+            var _label = treeHierarchy[n_type].label;
+            pgBrowser.Events.trigger(
+              'pgadmin:node:retrieval:error', 'statistics', xhr, error, message, item
+            );
+            if (!Alertify.pgHandleItemError(xhr, error, message, {
+              item: item,
+              info: treeHierarchy,
+            })) {
+              Alertify.pgNotifier(
+                error, xhr,
+                S(gettext('Error retrieving the information - %s')).sprintf(
+                  message || _label
+                ).value(),
+                function() {}
               );
-              if (!Alertify.pgHandleItemError(xhr, error, message, {
-                item: item,
-                info: treeHierarchy,
-              })) {
-                Alertify.pgNotifier(
-                  error, xhr,
-                  S(gettext('Error retrieving the information - %s')).sprintf(
-                    message || _label
-                  ).value(),
-                  function() {}
-                );
-              }
-              // show failed message.
-              $msgContainer.text(gettext('Failed to retrieve data from the server.'));
-            },
+            }
+            // show failed message.
+            $msgContainer.text(gettext('Failed to retrieve data from the server.'));
           });
         }
       }
@@ -300,7 +309,19 @@ define('misc.statistics', [
         $msgContainer.text(msg);
       }
     },
+    refreshStatistics: function(item, data, node) {
+      var that = this,
+        cache_flag = {
+          node_type: data._type,
+          url: node.generate_url(item, 'stats', data, true),
+        };
 
+      if (_.isEqual($(that.panel[0]).data('node-prop'), cache_flag)) {
+        // Reset the current item selection
+        $(that.panel[0]).data('node-prop', '');
+        that.showStatistics(item, data, node);
+      }
+    },
     showStatistics: function(item, data, node) {
       var self = this;
       if (!node) {
@@ -395,12 +416,22 @@ define('misc.statistics', [
           'pgadmin-browser:tree:selected',
           pgBrowser.NodeStatistics.showStatistics
         );
+        pgBrowser.Events.on(
+          'pgadmin-browser:tree:refreshing',
+          pgBrowser.NodeStatistics.refreshStatistics,
+          this
+        );
       } else {
         // We don't need to listen the tree item selection event.
         pgBrowser.Events.off(
           'pgadmin-browser:tree:selected',
           pgBrowser.NodeStatistics.showStatistics
         );
+        pgBrowser.Events.off(
+          'pgadmin-browser:tree:refreshing',
+          pgBrowser.NodeStatistics.refreshStatistics,
+          this
+        );
       }
     },
   });
