@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -14,8 +14,9 @@ from pgadmin import PgAdminModule
 
 MODULE_NAME = 'redirects'
 
-blueprint = PgAdminModule(MODULE_NAME, __name__,
-                          url_prefix='/')
+blueprint = PgAdminModule(
+    MODULE_NAME, __name__, url_prefix='/'
+)
 
 
 @blueprint.route('/')
